// LICENSE : MIT
"use strict";
/*
 かっこ類と隣接する文字の間のスペースの有無
 かっこの外側、内側ともにスペースを入れません。
 */

var _textlintRuleHelper = require("textlint-rule-helper");

var _matchIndex = require("match-index");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var brackets = ["\\[", "\\]", "（", "）", "［", "］", "「", "」", "『", "』"];

var leftBrackets = brackets.map(function (bracket) {
    return new RegExp("\([ 　]\)" + bracket, "g");
});
var rightBrackets = brackets.map(function (bracket) {
    return new RegExp(bracket + "\([ 　])", "g");
});
function reporter(context) {
    var Syntax = context.Syntax;
    var RuleError = context.RuleError;
    var report = context.report;
    var fixer = context.fixer;
    var getSource = context.getSource;

    var helper = new _textlintRuleHelper.RuleHelper();
    return _defineProperty({}, Syntax.Str, function (node) {
        if (helper.isChildNode(node, [Syntax.Link, Syntax.Image, Syntax.BlockQuote, Syntax.Emphasis])) {
            return;
        }
        var text = getSource(node);
        // 左にスペース
        leftBrackets.forEach(function (pattern) {
            (0, _matchIndex.matchCaptureGroupAll)(text, pattern).forEach(function (match) {
                var index = match.index;

                report(node, new RuleError("かっこの外側、内側ともにスペースを入れません。", {
                    index: index,
                    fix: fixer.replaceTextRange([index, index + 1], "")
                }));
            });
        });
        // 右にスペース
        rightBrackets.forEach(function (pattern) {
            (0, _matchIndex.matchCaptureGroupAll)(text, pattern).forEach(function (match) {
                var index = match.index;
                var text = match.text;

                report(node, new RuleError("かっこの外側、内側ともにスペースを入れません。", {
                    index: index,
                    fix: fixer.replaceTextRange([index, index + 1], "")
                }));
            });
        });
    });
}
module.exports = {
    linter: reporter,
    fixer: reporter
};
//# sourceMappingURL=index.js.map